Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(105)

Unified Diff: PRESUBMIT.py

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « LICENSE.md ('k') | WATCHLISTS » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: PRESUBMIT.py
diff --git a/PRESUBMIT.py b/PRESUBMIT.py
index ecd699b5a2537c8b2df4785bd3fa7ef5dcf462c9..848e9b52f1ad627b77aa863625936da041c9b21b 100644
--- a/PRESUBMIT.py
+++ b/PRESUBMIT.py
@@ -4,7 +4,7 @@
import cpplint
"""Top-level presubmit script for Fletch.
See http://dev.chromium.org/developers/how-tos/depottools/presubmit-scripts
for more details about the presubmit API built into gcl.
@@ -15,7 +15,7 @@ NO_LINTING = (
r"^package[\\\/]immi[\\\/]objc[\\\/].*",
r"^package[\\\/]service[\\\/]cc[\\\/].*"
r"^package[\\\/]service[\\\/]java[\\\/]jni[\\\/].*",
- r"^platforms[\\\/]stm[\\\/]disco_fletch[\\\/]generated[\\\/].*",
+ r"^platforms[\\\/]stm[\\\/]disco_dartino[\\\/]generated[\\\/].*",
r"^samples[\\\/]github[\\\/]ios[\\\/].*",
r"^samples[\\\/]buildbot[\\\/]cc[\\\/].*",
r"^samples[\\\/]buildbot[\\\/]ios[\\\/].*",
@@ -42,7 +42,7 @@ def CheckChangeOnCommit(input_api, output_api):
status_check = input_api.canned_checks.CheckTreeIsOpen(
input_api,
output_api,
- json_url='http://fletch-status.appspot.com/current?format=json')
+ json_url='http://dartino-status.appspot.com/current?format=json')
results.extend(status_check)
results.extend(RunLint(input_api, output_api))
return results
@@ -4,7 +4,7 @@
import cpplint
-"""Top-level presubmit script for Fletch.
+"""Top-level presubmit script for Dartino.
See http://dev.chromium.org/developers/how-tos/depottools/presubmit-scripts
for more details about the presubmit API built into gcl.
« no previous file with comments | « LICENSE.md ('k') | WATCHLISTS » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698